@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Email::Stuffer;
 # ABSTRACT: A more casual approach to creating and sending Email:: emails
-$Email::Stuffer::VERSION = '0.012';
+$Email::Stuffer::VERSION = '0.014';
 #pod =head1 SYNOPSIS
 #pod
 #pod   # Prepare the message
@@ -166,9 +166,10 @@ use strict;
 use Carp                   qw(croak);
 use File::Basename         ();
 use Params::Util 1.05      qw(_INSTANCE _INSTANCEDOES);
-use Email::MIME            ();
+use Email::MIME 1.920      ();
 use Email::MIME::Creator   ();
 use Email::Sender::Simple  ();
+use Module::Runtime        qw(require_module);
 
 #####################################################################
 # Constructor and Accessors
@@ -177,18 +178,45 @@ use Email::Sender::Simple  ();
 #pod
 #pod Creates a new, empty, Email::Stuffer object.
 #pod
+#pod You can pass a hashref of properties to set, including:
+#pod
+#pod =for :list
+#pod * to
+#pod * from
+#pod * cc
+#pod * bcc
+#pod * subject
+#pod * text_body
+#pod * html_body
+#pod * transport
+#pod
 #pod =cut
 
+my %IS_INIT_ARG = map {; $_ => 1 } qw(
+  to from cc bcc subject text_body html_body transport
+);
+
 sub new {
-	my $class = ref $_[0] || $_[0];
+	Carp::croak("new method called on Email::Stuffer instance") if ref $_[0];
+
+	my ($class, $arg) = @_;
 
 	my $self = bless {
 		parts      => [],
 		email      => Email::MIME->create(
 			header => [],
 			parts  => [],
-			),
-		}, $class;
+    ),
+  }, $class;
+
+  my @init_args = keys %{ $arg || {} };
+  if (my @bogus = grep {; ! $IS_INIT_ARG{$_} } @init_args) {
+    Carp::croak("illegal arguments to Email::Stuffer->new: @bogus");
+  }
+
+	for my $init_arg (@init_args) {
+    $self->$init_arg($arg->{$init_arg});
+	}
 
 	$self;
 }
@@ -248,7 +276,9 @@ sub header {
 
 sub to {
 	my $self = shift()->_self;
-	$self->{email}->header_str_set(To => join(q{, }, @_)) ? $self : undef;
+	Carp::croak("to is a required field") unless defined $_[0];
+	$self->{email}->header_str_set(To => join(q{, }, @_));
+	return $self;
 }
 
 #pod =method from $address
@@ -259,7 +289,9 @@ sub to {
 
 sub from {
 	my $self = shift()->_self;
-	$self->{email}->header_str_set(From => shift) ? $self : undef;
+	Carp::croak("from is a required field") unless defined $_[0];
+	$self->{email}->header_str_set(From => shift);
+	return $self;
 }
 
 #pod =method cc $address
@@ -270,7 +302,8 @@ sub from {
 
 sub cc {
 	my $self = shift()->_self;
-	$self->{email}->header_str_set(Cc => join(q{, }, @_)) ? $self : undef;
+	$self->{email}->header_str_set(Cc => join(q{, }, @_));
+	return $self;
 }
 
 #pod =method bcc $address
@@ -281,7 +314,8 @@ sub cc {
 
 sub bcc {
 	my $self = shift()->_self;
-	$self->{email}->header_str_set(Bcc => join(q{, }, @_)) ? $self : undef;
+	$self->{email}->header_str_set(Bcc => join(q{, }, @_));
+	return $self;
 }
 
 #pod =method subject $text
@@ -292,7 +326,9 @@ sub bcc {
 
 sub subject {
 	my $self = shift()->_self;
-	$self->{email}->header_str_set(Subject => shift) ? $self : undef;
+	Carp::croak("subject is a required field") unless defined $_[0];
+	$self->{email}->header_str_set(Subject => shift);
+	return $self;
 }
 
 #####################################################################
@@ -374,7 +410,7 @@ sub _detect_content_type {
 	my ($filename, $body) = @_;
 
 	if (defined($filename)) {
-		if ($filename =~ /\.([a-z]{3,4})\z/) {
+		if ($filename =~ /\.([a-zA-Z]{3,4})\z/) {
 			my $content_type = {
 				'gif'  => 'image/gif',
 				'png'  => 'image/png',
@@ -385,7 +421,8 @@ sub _detect_content_type {
 				'html' => 'text/html',
 				'css'  => 'text/css',
 				'pdf'  => 'application/pdf',
-			}->{$1};
+				'wav'  => 'audio/wav',
+			}->{lc($1)};
 			return $content_type if defined $content_type;
 		}
 	}
@@ -451,6 +488,7 @@ sub attach_file {
 
 	# Support IO::All::File arguments
 	if ( Params::Util::_INSTANCE($body_arg, 'IO::All::File') ) {
+		$body_arg->binmode;
 		$name = $body_arg->name;
 		$body = $body_arg->all;
 
@@ -519,6 +557,7 @@ sub transport {
 		  my $class = $moniker =~ s/\A=//
 		            ? $moniker
 		            : "Email::Sender::Transport::$moniker";
+		  require_module($class);
 			my $transport = $class->new(@arg);
 			$self->{transport} = $transport;
 		}
@@ -676,7 +715,7 @@ Email::Stuffer - A more casual approach to creating and sending Email:: emails
 
 =head1 VERSION
 
-version 0.012
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -808,6 +847,44 @@ B<are not> chainable.
 
 Creates a new, empty, Email::Stuffer object.
 
+You can pass a hashref of properties to set, including:
+
+=over 4
+
+=item *
+
+to
+
+=item *
+
+from
+
+=item *
+
+cc
+
+=item *
+
+bcc
+
+=item *
+
+subject
+
+=item *
+
+text_body
+
+=item *
+
+html_body
+
+=item *
+
+transport
+
+=back
+
 =head2 header_names
 
 Returns, as a list, all of the headers currently set for the Email
@@ -977,6 +1054,74 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=for stopwords adam adamk@cpan.org adam@phase-n.com Aristotle Pagaltzis Arthur Axel 'fREW' Schmidt Chase Whitener CosmicNet John Napiorkowski Kevin Tew Kieren Diment Kris Matthews Manni Heumann Ross Attrill tokuhirom
+
+=over 4
+
+=item *
+
+adam <adam@88f4d9cd-8a04-0410-9d60-8f63309c3137>
+
+=item *
+
+adamk@cpan.org <adamk@cpan.org@88f4d9cd-8a04-0410-9d60-8f63309c3137>
+
+=item *
+
+adam@phase-n.com <adam@phase-n.com@88f4d9cd-8a04-0410-9d60-8f63309c3137>
+
+=item *
+
+Aristotle Pagaltzis <pagaltzis@gmx.de>
+
+=item *
+
+Arthur Axel 'fREW' Schmidt <frioux@gmail.com>
+
+=item *
+
+Chase Whitener <chase.whitener@infotechfl.com>
+
+=item *
+
+CosmicNet <webmaster@cosmicperl.com>
+
+=item *
+
+John Napiorkowski <jjn1056@yahoo.com>
+
+=item *
+
+Kevin Tew <tewk@tan.tewk.com>
+
+=item *
+
+Kieren Diment <kd@fenchurch.local>
+
+=item *
+
+Kris Matthews <krismatth@icloud.com>
+
+=item *
+
+Kris Matthews <kris@tigerlms.com>
+
+=item *
+
+Manni Heumann <github@lxxi.org>
+
+=item *
+
+Ross Attrill <ross.attrill@gmail.com>
+
+=item *
+
+tokuhirom <tokuhirom@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2004 by Adam Kennedy and Ricardo SIGNES.
